from em_tasks.utils.pipelines.base import BasePipeline
from em_tasks.utils.product_converters import AmzProductConverter

from em_tasks import logger


class AmzProductsFilterPipeline(BasePipeline):
  def __init__(self, marketplace = 'us', weight_max = 2.5, dimension_max = 30, sales_rank_min = 1500000):
    self.weight_max = weight_max
    self.dimension_max = dimension_max
    self.sales_rank_min = sales_rank_min
    self.pc = AmzProductConverter(marketplace.lower())

  def execute(self, product):
    exist = product.get('existence', True)
    if not exist:
      logger.debug('[NotExist]')
      return

    has_only_default_variant = product.get('has_only_default_variant', True)
    if not has_only_default_variant:
      logger.debug('[MultipleVariant]')
      return

    weight = self.pc.get_weight(product)
    if weight and weight > self.weight_max:
      logger.debug('[OverWeight] %s', weight)
      return

    is_fragile = self.pc.is_fragile(product)
    if is_fragile:
      logger.debug('[Fragile] ASIN: %s, Title: %s', product.get('asin', ''), product.get('title', ''))
      return

    is_alcohol = self.pc.is_alcohol(product)
    if is_alcohol:
      logger.debug('[Alcohol] ASIN: %s, Title: %s', product.get('asin', ''), product.get('title', ''))
      return

    is_contains_food_or_beverage = self.pc.is_contains_food_or_beverage(product)
    if is_contains_food_or_beverage:
      logger.debug('[FoodOrBeverage] ASIN: %s, Title: %s', product.get('asin', ''), product.get('title', ''))
      return

    is_batteries_included = self.pc.is_batteries_included(product)
    if is_batteries_included:
      logger.debug('[IncludeBatteries] ASIN: %s, Title: %s', product.get('asin', ''), product.get('title', ''))
      return

    is_liquid = self.pc.is_liquid(product)
    if is_liquid:
      logger.debug('[Liquid] ASIN: %s, Title: %s', product.get('asin', ''), product.get('title', ''))
      # return

    is_plant_or_seed = self.pc.is_plant_or_seed(product)
    if is_plant_or_seed:
      logger.debug('[PlantOrSeed] ASIN: %s, Title: %s', product.get('asin', ''), product.get('title', ''))
      return

    dimensions = self.pc.get_dimensions(product)
    if dimensions:
      width = dimensions.get('width', None)
      height = dimensions.get('height', None)
      length = dimensions.get('length', None)
      if (width and width > self.dimension_max) or (height and height > self.dimension_max) or (length and length > self.dimension_max):
        logger.debug('[OverSize] %s', dimensions)
        return

    sales_rank = self.pc.get_sales_rank(product)
    if sales_rank and sales_rank > self.sales_rank_min:
      logger.debug('[SalesRankLow] %s', sales_rank)
      return

    return product
